## Version 0.0.7

This new version includes several enhancements and updates to improve the functionality and consistency of the LlamaBot.

### New Features

- Added 'llama-index' to the list of dependencies to enhance the functionality of the bot (196cdc) (Eric Ma)
- Updated the `__call__` method of QueryBot for better performance and efficiency (b1840c) (Eric Ma)

### Bug Fixes

- Replaced a complex version with a simplified one to fix performance issues (f17655) (Eric Ma)
- Ensured the return of strings is consistent across all functions to fix inconsistency issues (88d62a) (Eric Ma)

### Deprecations

- Changed the default argument of `return_sources` to True. This might affect the behavior of functions that rely on the previous default value (a03db6) (Eric Ma)
